==> nextalarm_0.2.8.tar.gz: nextalarm-0.2.8/src/nextalarm_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="65"/>
        <source>alarms in next %1 h</source>
        <translation>Alarme innerhalb von %1h</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="161"/>
        <source>d</source>
        <translation type="unfinished">t</translation>
    </message>		
    <message>
        <location filename="alarmwindow.cpp" line="219"/>
        <source>--:--</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation>Next Alarm Einstellungen</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="38"/>
        <source>Font</source>
        <translation>Schrift</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="68"/>
        <source>B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="86"/>
        <source>I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="103"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="110"/>
        <source>12:48</source>
        <translation></translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="132"/>
        <source>Show</source>
        <translation>Weisen</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="149"/>
        <source>Alarms only</source>
        <translation>Nur Alarme</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Alarms + Calendar</source>
        <translation>Alarme + Kalender</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="159"/>
        <source>All Events</source>
        <translation>Alle Ereignisse</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="167"/>
        <source>Lines</source>
        <translation>Zeilen</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="193"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="222"/>
        <source>recurrent</source>
        <translation>Wiederkehrend</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="229"/>
        <source>Frame (h)</source>
        <translation>Zeitspanne in Std.</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="251"/>
        <source>Time Remain</source>
        <translation>Verbleibende Zeit</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="270"/>
        <source>Header</source>
        <translation>Kopfzeile</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="282"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="294"/>
        <source>Show empty</source>
        <translation>Immer anzeigen</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="307"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="314"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="118"/>
        <source>Next Alarm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="119"/>
        <source>Developed with</source>
        <translation>Entwickelt mit</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="120"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation>Desktop Widget, das die Zeit der nächsten Alarme anzeigt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="121"/>
        <source>Send reports to:</source>
        <translation>Sende Berichte zu:</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="128"/>
        <source>About Next Alarm</source>
        <translation>Über Next Alarm</translation>
    </message>
</context>
</TS>

==> nextalarm_0.2.9.tar.gz: nextalarm-0.2.9/src/nextalarm_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>AlarmWindow</name>
    <message>
        <location filename="alarmwindow.ui" line="14"/>
        <source>AlarmWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="65"/>
        <source>alarms in next %1 h</source>
        <translation>Alarme innerhalb von %1h</translation>
    </message>
    <message>
        <location filename="alarmwindow.cpp" line="161"/>
        <source>d</source>
        <translation type="unfinished">t</translation>
    </message>		
    <message>
        <location filename="alarmwindow.cpp" line="219"/>
        <source>--:--</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="settingsdialog.ui" line="19"/>
        <source>Next Alarm settings</source>
        <translation>Next Alarm Einstellungen</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="38"/>
        <source>Font</source>
        <translation>Schrift</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="68"/>
        <source>B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="86"/>
        <source>I</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="103"/>
        <source>Color</source>
        <translation>Farbe</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="110"/>
        <source>12:48</source>
        <translation></translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="132"/>
        <source>Show</source>
        <translation>Weisen</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="149"/>
        <source>Alarms only</source>
        <translation>Nur Alarme</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="154"/>
        <source>Alarms + Calendar</source>
        <translation>Alarme + Kalender</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="159"/>
        <source>All Events</source>
        <translation>Alle Ereignisse</translation>
    </message>    
    <message>
        <location filename="settingsdialog.ui" line="167"/>
        <source>Lines</source>
        <translation>Zeilen</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="193"/>
        <source>Width</source>
        <translation>Breite</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="222"/>
        <source>recurrent</source>
        <translation>Wiederkehrend</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="229"/>
        <source>Frame (h)</source>
        <translation>Zeitspanne in Std.</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="368"/>
        <source>Show Time Remain</source>
        <translation>Verbleibende Zeit</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="270"/>
        <source>Header</source>
        <translation>Kopfzeile</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="282"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="294"/>
        <source>Show empty</source>
        <translation>Immer anzeigen</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="307"/>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <location filename="settingsdialog.ui" line="314"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="118"/>
        <source>Next Alarm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="119"/>
        <source>Developed with</source>
        <translation>Entwickelt mit</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="120"/>
        <source>Desktop widget, showing time of next alarms</source>
        <translation>Desktop Widget, das die Zeit der nächsten Alarme anzeigt</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="121"/>
        <source>Send reports to:</source>
        <translation>Sende Berichte zu:</translation>
    </message>
    <message>
        <location filename="settingsdialog.cpp" line="128"/>
        <source>About Next Alarm</source>
        <translation>Über Next Alarm</translation>
    </message>
</context>
</TS>
